#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import endpoint
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class EndpointTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Endpoint", js["resourceType"])
        return endpoint.Endpoint(js)
    
    def testEndpoint1(self):
        inst = self.instantiate_from("endpoint-example-iid.json")
        self.assertIsNotNone(inst, "Must have instantiated a Endpoint instance")
        self.implEndpoint1(inst)
        
        js = inst.as_json()
        self.assertEqual("Endpoint", js["resourceType"])
        inst2 = endpoint.Endpoint(js)
        self.implEndpoint1(inst2)
    
    def implEndpoint1(self, inst):
        self.assertEqual(force_bytes(inst.address), force_bytes("https://pacs.hospital.org/IHEInvokeImageDisplay"))
        self.assertEqual(force_bytes(inst.connectionType.code), force_bytes("ihe-iid"))
        self.assertEqual(force_bytes(inst.connectionType.system), force_bytes("http://hl7.org/fhir/endpoint-connection-type"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example-iid"))
        self.assertEqual(force_bytes(inst.name), force_bytes("PACS Hospital Invoke Image Display endpoint"))
        self.assertEqual(force_bytes(inst.payloadType[0].text), force_bytes("DICOM IID"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testEndpoint2(self):
        inst = self.instantiate_from("endpoint-example-wadors.json")
        self.assertIsNotNone(inst, "Must have instantiated a Endpoint instance")
        self.implEndpoint2(inst)
        
        js = inst.as_json()
        self.assertEqual("Endpoint", js["resourceType"])
        inst2 = endpoint.Endpoint(js)
        self.implEndpoint2(inst2)
    
    def implEndpoint2(self, inst):
        self.assertEqual(force_bytes(inst.address), force_bytes("https://pacs.hospital.org/wado-rs"))
        self.assertEqual(force_bytes(inst.connectionType.code), force_bytes("dicom-wado-rs"))
        self.assertEqual(force_bytes(inst.connectionType.system), force_bytes("http://hl7.org/fhir/endpoint-connection-type"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example-wadors"))
        self.assertEqual(force_bytes(inst.name), force_bytes("PACS Hospital DICOM WADO-RS endpoint"))
        self.assertEqual(force_bytes(inst.payloadMimeType[0]), force_bytes("application/dicom"))
        self.assertEqual(force_bytes(inst.payloadType[0].text), force_bytes("DICOM WADO-RS"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testEndpoint3(self):
        inst = self.instantiate_from("endpoint-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Endpoint instance")
        self.implEndpoint3(inst)
        
        js = inst.as_json()
        self.assertEqual("Endpoint", js["resourceType"])
        inst2 = endpoint.Endpoint(js)
        self.implEndpoint3(inst2)
    
    def implEndpoint3(self, inst):
        self.assertEqual(force_bytes(inst.address), force_bytes("http://fhir3.healthintersections.com.au/open/CarePlan"))
        self.assertEqual(force_bytes(inst.connectionType.code), force_bytes("hl7-fhir-rest"))
        self.assertEqual(force_bytes(inst.connectionType.system), force_bytes("http://hl7.org/fhir/endpoint-connection-type"))
        self.assertEqual(force_bytes(inst.contact[0].system), force_bytes("email"))
        self.assertEqual(force_bytes(inst.contact[0].use), force_bytes("work"))
        self.assertEqual(force_bytes(inst.contact[0].value), force_bytes("endpointmanager@example.org"))
        self.assertEqual(force_bytes(inst.header[0]), force_bytes("bearer-code BASGS534s4"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org/enpoint-identifier"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("epcp12"))
        self.assertEqual(force_bytes(inst.name), force_bytes("Health Intersections CarePlan Hub"))
        self.assertEqual(force_bytes(inst.payloadMimeType[0]), force_bytes("application/fhir+xml"))
        self.assertEqual(force_bytes(inst.payloadType[0].coding[0].code), force_bytes("CarePlan"))
        self.assertEqual(force_bytes(inst.payloadType[0].coding[0].system), force_bytes("http://hl7.org/fhir/resource-types"))
        self.assertEqual(inst.period.start.date, FHIRDate("2014-09-01").date)
        self.assertEqual(inst.period.start.as_json(), "2014-09-01")
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import compartmentdefinition
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class CompartmentDefinitionTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("CompartmentDefinition", js["resourceType"])
        return compartmentdefinition.CompartmentDefinition(js)
    
    def testCompartmentDefinition1(self):
        inst = self.instantiate_from("compartmentdefinition-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a CompartmentDefinition instance")
        self.implCompartmentDefinition1(inst)
        
        js = inst.as_json()
        self.assertEqual("CompartmentDefinition", js["resourceType"])
        inst2 = compartmentdefinition.CompartmentDefinition(js)
        self.implCompartmentDefinition1(inst2)
    
    def implCompartmentDefinition1(self, inst):
        self.assertEqual(force_bytes(inst.code), force_bytes("Device"))
        self.assertEqual(force_bytes(inst.contact[0].name), force_bytes("[string]"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://hl7.org/fhir"))
        self.assertEqual(inst.date.date, FHIRDate("2017-02-24").date)
        self.assertEqual(inst.date.as_json(), "2017-02-24")
        self.assertEqual(force_bytes(inst.description), force_bytes("The set of resources associated with a particular Device (example with Communication and CommunicationRequest resourses only)."))
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].code), force_bytes("US"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].display), force_bytes("United States of America (the)"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].system), force_bytes("urn:iso:std:iso:3166"))
        self.assertEqual(force_bytes(inst.name), force_bytes("EXAMPLE"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("Health Level Seven International (FHIR Infrastructure)"))
        self.assertEqual(force_bytes(inst.purpose), force_bytes("Provides an example of a FHIR compartment definition based on the Device resource type."))
        self.assertEqual(force_bytes(inst.resource[0].code), force_bytes("Communication"))
        self.assertEqual(force_bytes(inst.resource[0].documentation), force_bytes("The device used as the message sender and recipient"))
        self.assertEqual(force_bytes(inst.resource[0].param[0]), force_bytes("sender"))
        self.assertEqual(force_bytes(inst.resource[0].param[1]), force_bytes("recipient"))
        self.assertEqual(force_bytes(inst.resource[1].code), force_bytes("CommunicationRequest"))
        self.assertEqual(force_bytes(inst.resource[1].documentation), force_bytes("The device used as the message sender and recipient"))
        self.assertEqual(force_bytes(inst.resource[1].param[0]), force_bytes("sender"))
        self.assertEqual(force_bytes(inst.resource[1].param[1]), force_bytes("recipient"))
        self.assertTrue(inst.search)
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Base FHIR compartment definition for Device(example)"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/CompartmentDefinition/example"))
        self.assertEqual(force_bytes(inst.useContext[0].code.code), force_bytes("focus"))
        self.assertEqual(force_bytes(inst.useContext[0].code.system), force_bytes("http://hl7.org/fhir/usage-context-type"))
        self.assertEqual(force_bytes(inst.useContext[0].valueCodeableConcept.coding[0].code), force_bytes("Device"))
        self.assertEqual(force_bytes(inst.useContext[0].valueCodeableConcept.coding[0].system), force_bytes("http://hl7.org/fhir/resource-types"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import procedure
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class ProcedureTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Procedure", js["resourceType"])
        return procedure.Procedure(js)
    
    def testProcedure1(self):
        inst = self.instantiate_from("procedure-example-colonoscopy.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure1(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure1(inst2)
    
    def implProcedure1(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("73761001"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Colonoscopy (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Colonoscopy"))
        self.assertEqual(force_bytes(inst.id), force_bytes("colonoscopy"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12345"))
        self.assertFalse(inst.notDone)
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Colonoscopy with complication</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedure2(self):
        inst = self.instantiate_from("procedure-example-f003-abscess.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure2(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure2(inst2)
    
    def implProcedure2(self, inst):
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].code), force_bytes("83030008"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].display), force_bytes("Retropharyngeal area"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("172960003"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Incision of retropharyngeal abscess"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.followUp[0].text), force_bytes("described in care plan"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f003"))
        self.assertEqual(force_bytes(inst.outcome.text), force_bytes("removal of the retropharyngeal abscess"))
        self.assertEqual(inst.performedPeriod.end.date, FHIRDate("2013-03-24T10:30:10+01:00").date)
        self.assertEqual(inst.performedPeriod.end.as_json(), "2013-03-24T10:30:10+01:00")
        self.assertEqual(inst.performedPeriod.start.date, FHIRDate("2013-03-24T09:30:10+01:00").date)
        self.assertEqual(inst.performedPeriod.start.as_json(), "2013-03-24T09:30:10+01:00")
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].code), force_bytes("01.000"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].display), force_bytes("Arts"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].system), force_bytes("urn:oid:2.16.840.1.113883.2.4.15.111"))
        self.assertEqual(force_bytes(inst.performer[0].role.text), force_bytes("Care role"))
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("abcess in retropharyngeal area"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedure3(self):
        inst = self.instantiate_from("procedure-example-biopsy.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure3(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure3(inst2)
    
    def implProcedure3(self, inst):
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].code), force_bytes("368225008"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].display), force_bytes("Entire Left Forearm"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.bodySite[0].text), force_bytes("Left forearm"))
        self.assertEqual(force_bytes(inst.category.coding[0].code), force_bytes("103693007"))
        self.assertEqual(force_bytes(inst.category.coding[0].display), force_bytes("Diagnostic procedure (procedure)"))
        self.assertEqual(force_bytes(inst.category.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.category.text), force_bytes("Diagnostic procedure"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("90105005"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Biopsy of soft tissue of forearm (Procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Biopsy of suspected melanoma L) arm"))
        self.assertEqual(force_bytes(inst.complication[0].coding[0].code), force_bytes("67750007"))
        self.assertEqual(force_bytes(inst.complication[0].coding[0].display), force_bytes("Ineffective airway clearance (finding)"))
        self.assertEqual(force_bytes(inst.complication[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.complication[0].text), force_bytes("Ineffective airway clearance"))
        self.assertEqual(force_bytes(inst.followUp[0].text), force_bytes("Review in clinic"))
        self.assertEqual(force_bytes(inst.id), force_bytes("biopsy"))
        self.assertEqual(force_bytes(inst.note[0].text), force_bytes("Standard Biopsy"))
        self.assertEqual(inst.performedDateTime.date, FHIRDate("2014-02-03").date)
        self.assertEqual(inst.performedDateTime.as_json(), "2014-02-03")
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("Dark lesion l) forearm. getting darker last 3 months."))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Biopsy of suspected melanoma L) arm</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.usedCode[0].coding[0].code), force_bytes("79068005"))
        self.assertEqual(force_bytes(inst.usedCode[0].coding[0].display), force_bytes("Needle, device (physical object)"))
        self.assertEqual(force_bytes(inst.usedCode[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.usedCode[0].text), force_bytes("30-guage needle"))
    
    def testProcedure4(self):
        inst = self.instantiate_from("procedure-example-f201-tpf.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure4(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure4(inst2)
    
    def implProcedure4(self, inst):
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].code), force_bytes("272676008"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].display), force_bytes("Sphenoid bone"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("367336001"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Chemotherapy"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f201"))
        self.assertEqual(force_bytes(inst.note[0].text), force_bytes("Eerste neo-adjuvante TPF-kuur bij groot proces in sphenoid met intracraniale uitbreiding."))
        self.assertEqual(inst.performedPeriod.end.date, FHIRDate("2013-01-28T14:27:00+01:00").date)
        self.assertEqual(inst.performedPeriod.end.as_json(), "2013-01-28T14:27:00+01:00")
        self.assertEqual(inst.performedPeriod.start.date, FHIRDate("2013-01-28T13:31:00+01:00").date)
        self.assertEqual(inst.performedPeriod.start.as_json(), "2013-01-28T13:31:00+01:00")
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].code), force_bytes("310512001"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].display), force_bytes("Medical oncologist"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("DiagnosticReport/f201"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedure5(self):
        inst = self.instantiate_from("procedure-example-f002-lung.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure5(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure5(inst2)
    
    def implProcedure5(self, inst):
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].code), force_bytes("39607008"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].display), force_bytes("Lung structure"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("359615001"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Partial lobectomy of lung"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.followUp[0].text), force_bytes("described in care plan"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f002"))
        self.assertEqual(force_bytes(inst.outcome.text), force_bytes("improved blood circulation"))
        self.assertEqual(inst.performedPeriod.end.date, FHIRDate("2013-03-08T09:30:10+01:00").date)
        self.assertEqual(inst.performedPeriod.end.as_json(), "2013-03-08T09:30:10+01:00")
        self.assertEqual(inst.performedPeriod.start.date, FHIRDate("2013-03-08T09:00:10+01:00").date)
        self.assertEqual(inst.performedPeriod.start.as_json(), "2013-03-08T09:00:10+01:00")
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].code), force_bytes("01.000"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].display), force_bytes("Arts"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].system), force_bytes("urn:oid:2.16.840.1.113883.2.4.15.111"))
        self.assertEqual(force_bytes(inst.performer[0].role.text), force_bytes("Care role"))
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("Malignant tumor of lung"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedure6(self):
        inst = self.instantiate_from("procedure-example-ambulation.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure6(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure6(inst2)
    
    def implProcedure6(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("62013009"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Ambulating patient (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Ambulation"))
        self.assertEqual(force_bytes(inst.id), force_bytes("ambulation"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12345"))
        self.assertTrue(inst.notDone)
        self.assertEqual(force_bytes(inst.notDoneReason.coding[0].code), force_bytes("398254007"))
        self.assertEqual(force_bytes(inst.notDoneReason.coding[0].display), force_bytes("  Pre-eclampsia (disorder)"))
        self.assertEqual(force_bytes(inst.notDoneReason.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.notDoneReason.text), force_bytes("Pre-eclampsia"))
        self.assertEqual(force_bytes(inst.status), force_bytes("suspended"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Ambulation procedure was not done</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedure7(self):
        inst = self.instantiate_from("procedure-example-education.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure7(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure7(inst2)
    
    def implProcedure7(self, inst):
        self.assertEqual(force_bytes(inst.category.coding[0].code), force_bytes("311401005"))
        self.assertEqual(force_bytes(inst.category.coding[0].display), force_bytes("Patient education (procedure)"))
        self.assertEqual(force_bytes(inst.category.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.category.text), force_bytes("Education"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("48023004"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Breast self-examination technique education (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Health education - breast examination"))
        self.assertEqual(force_bytes(inst.id), force_bytes("education"))
        self.assertEqual(inst.performedDateTime.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.performedDateTime.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("early detection of breast mass"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Health education - breast examination for early detection of breast mass</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedure8(self):
        inst = self.instantiate_from("procedure-example-colon-biopsy.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure8(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure8(inst2)
    
    def implProcedure8(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("76164006"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Biopsy of colon (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Biopsy of colon"))
        self.assertEqual(force_bytes(inst.id), force_bytes("colon-biopsy"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12345"))
        self.assertFalse(inst.notDone)
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Biopsy of colon, which was part of colonoscopy</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedure9(self):
        inst = self.instantiate_from("procedure-example-appendectomy-narrative.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure9(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure9(inst2)
    
    def implProcedure9(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("appendectomy-narrative"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Routine Appendectomy in April 2013 performed by Dr Cecil Surgeon</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
    
    def testProcedure10(self):
        inst = self.instantiate_from("procedure-example-f004-tracheotomy.json")
        self.assertIsNotNone(inst, "Must have instantiated a Procedure instance")
        self.implProcedure10(inst)
        
        js = inst.as_json()
        self.assertEqual("Procedure", js["resourceType"])
        inst2 = procedure.Procedure(js)
        self.implProcedure10(inst2)
    
    def implProcedure10(self, inst):
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].code), force_bytes("83030008"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].display), force_bytes("Retropharyngeal area"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("48387007"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Tracheotomy"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.followUp[0].text), force_bytes("described in care plan"))
        self.assertEqual(force_bytes(inst.id), force_bytes("f004"))
        self.assertEqual(force_bytes(inst.outcome.text), force_bytes("removal of the retropharyngeal abscess"))
        self.assertEqual(inst.performedPeriod.end.date, FHIRDate("2013-03-22T10:30:10+01:00").date)
        self.assertEqual(inst.performedPeriod.end.as_json(), "2013-03-22T10:30:10+01:00")
        self.assertEqual(inst.performedPeriod.start.date, FHIRDate("2013-03-22T09:30:10+01:00").date)
        self.assertEqual(inst.performedPeriod.start.as_json(), "2013-03-22T09:30:10+01:00")
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].code), force_bytes("01.000"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].display), force_bytes("Arts"))
        self.assertEqual(force_bytes(inst.performer[0].role.coding[0].system), force_bytes("urn:oid:2.16.840.1.113883.2.4.15.111"))
        self.assertEqual(force_bytes(inst.performer[0].role.text), force_bytes("Care role"))
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("ensure breathing during surgery"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/SupplyDelivery) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class SupplyDelivery(domainresource.DomainResource):
    """ Delivery of bulk Supplies.
    
    Record of delivery of what is supplied.
    """
    
    resource_type = "SupplyDelivery"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.basedOn = None
        """ Fulfills plan, proposal or order.
        List of `FHIRReference` items referencing `SupplyRequest` (represented as `dict` in JSON). """
        
        self.destination = None
        """ Where the Supply was sent.
        Type `FHIRReference` referencing `Location` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ External identifier.
        Type `Identifier` (represented as `dict` in JSON). """
        
        self.occurrenceDateTime = None
        """ When event occurred.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.occurrencePeriod = None
        """ When event occurred.
        Type `Period` (represented as `dict` in JSON). """
        
        self.occurrenceTiming = None
        """ When event occurred.
        Type `Timing` (represented as `dict` in JSON). """
        
        self.partOf = None
        """ Part of referenced event.
        List of `FHIRReference` items referencing `SupplyDelivery, Contract` (represented as `dict` in JSON). """
        
        self.patient = None
        """ Patient for whom the item is supplied.
        Type `FHIRReference` referencing `Patient` (represented as `dict` in JSON). """
        
        self.receiver = None
        """ Who collected the Supply.
        List of `FHIRReference` items referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.status = None
        """ in-progress | completed | abandoned | entered-in-error.
        Type `str`. """
        
        self.suppliedItem = None
        """ The item that is delivered or supplied.
        Type `SupplyDeliverySuppliedItem` (represented as `dict` in JSON). """
        
        self.supplier = None
        """ Dispenser.
        Type `FHIRReference` referencing `Practitioner, Organization` (represented as `dict` in JSON). """
        
        self.type = None
        """ Category of dispense event.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(SupplyDelivery, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(SupplyDelivery, self).elementProperties()
        js.extend([
            ("basedOn", "basedOn", fhirreference.FHIRReference, True, None, False),
            ("destination", "destination", fhirreference.FHIRReference, False, None, False),
            ("identifier", "identifier", identifier.Identifier, False, None, False),
            ("occurrenceDateTime", "occurrenceDateTime", fhirdate.FHIRDate, False, "occurrence", False),
            ("occurrencePeriod", "occurrencePeriod", period.Period, False, "occurrence", False),
            ("occurrenceTiming", "occurrenceTiming", timing.Timing, False, "occurrence", False),
            ("partOf", "partOf", fhirreference.FHIRReference, True, None, False),
            ("patient", "patient", fhirreference.FHIRReference, False, None, False),
            ("receiver", "receiver", fhirreference.FHIRReference, True, None, False),
            ("status", "status", str, False, None, False),
            ("suppliedItem", "suppliedItem", SupplyDeliverySuppliedItem, False, None, False),
            ("supplier", "supplier", fhirreference.FHIRReference, False, None, False),
            ("type", "type", codeableconcept.CodeableConcept, False, None, False),
        ])
        return js


from . import backboneelement

class SupplyDeliverySuppliedItem(backboneelement.BackboneElement):
    """ The item that is delivered or supplied.
    
    The item that is being delivered or has been supplied.
    """
    
    resource_type = "SupplyDeliverySuppliedItem"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.itemCodeableConcept = None
        """ Medication, Substance, or Device supplied.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.itemReference = None
        """ Medication, Substance, or Device supplied.
        Type `FHIRReference` referencing `Medication, Substance, Device` (represented as `dict` in JSON). """
        
        self.quantity = None
        """ Amount dispensed.
        Type `Quantity` (represented as `dict` in JSON). """
        
        super(SupplyDeliverySuppliedItem, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(SupplyDeliverySuppliedItem, self).elementProperties()
        js.extend([
            ("itemCodeableConcept", "itemCodeableConcept", codeableconcept.CodeableConcept, False, "item", False),
            ("itemReference", "itemReference", fhirreference.FHIRReference, False, "item", False),
            ("quantity", "quantity", quantity.Quantity, False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']
try:
    from . import quantity
except ImportError:
    quantity = sys.modules[__package__ + '.quantity']
try:
    from . import timing
except ImportError:
    timing = sys.modules[__package__ + '.timing']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import questionnaireresponse
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class QuestionnaireResponseTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("QuestionnaireResponse", js["resourceType"])
        return questionnaireresponse.QuestionnaireResponse(js)
    
    def testQuestionnaireResponse1(self):
        inst = self.instantiate_from("questionnaireresponse-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a QuestionnaireResponse instance")
        self.implQuestionnaireResponse1(inst)
        
        js = inst.as_json()
        self.assertEqual("QuestionnaireResponse", js["resourceType"])
        inst2 = questionnaireresponse.QuestionnaireResponse(js)
        self.implQuestionnaireResponse1(inst2)
    
    def implQuestionnaireResponse1(self, inst):
        self.assertEqual(inst.authored.date, FHIRDate("2013-02-19T14:15:00-05:00").date)
        self.assertEqual(inst.authored.as_json(), "2013-02-19T14:15:00-05:00")
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("patsub"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("order"))
        self.assertEqual(force_bytes(inst.contained[2].id), force_bytes("questauth"))
        self.assertEqual(force_bytes(inst.id), force_bytes("3141"))
        self.assertEqual(force_bytes(inst.identifier.system), force_bytes("http://example.org/fhir/NamingSystem/questionnaire-ids"))
        self.assertEqual(force_bytes(inst.identifier.value), force_bytes("Q12349876"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[0].answer[0].valueCoding.code), force_bytes("1"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://cancer.questionnaire.org/system/code/yesno"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[0].linkId), force_bytes("1.1.1.1"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[1].answer[0].valueCoding.code), force_bytes("1"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[1].answer[0].valueCoding.system), force_bytes("http://cancer.questionnaire.org/system/code/yesno"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[1].linkId), force_bytes("1.1.1.2"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[2].answer[0].valueCoding.code), force_bytes("0"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://cancer.questionnaire.org/system/code/yesno"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].item[2].linkId), force_bytes("1.1.1.3"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].item[0].linkId), force_bytes("1.1.1"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].valueCoding.code), force_bytes("1"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].valueCoding.system), force_bytes("http://cancer.questionnaire.org/system/code/yesno"))
        self.assertEqual(force_bytes(inst.item[0].item[0].linkId), force_bytes("1.1"))
        self.assertEqual(force_bytes(inst.item[0].linkId), force_bytes("1"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testQuestionnaireResponse2(self):
        inst = self.instantiate_from("questionnaireresponse-example-f201-lifelines.json")
        self.assertIsNotNone(inst, "Must have instantiated a QuestionnaireResponse instance")
        self.implQuestionnaireResponse2(inst)
        
        js = inst.as_json()
        self.assertEqual("QuestionnaireResponse", js["resourceType"])
        inst2 = questionnaireresponse.QuestionnaireResponse(js)
        self.implQuestionnaireResponse2(inst2)
    
    def implQuestionnaireResponse2(self, inst):
        self.assertEqual(inst.authored.date, FHIRDate("2013-06-18T00:00:00+01:00").date)
        self.assertEqual(inst.authored.as_json(), "2013-06-18T00:00:00+01:00")
        self.assertEqual(force_bytes(inst.id), force_bytes("f201"))
        self.assertEqual(force_bytes(inst.item[0].item[0].answer[0].valueString), force_bytes("I am allergic to house dust"))
        self.assertEqual(force_bytes(inst.item[0].item[0].linkId), force_bytes("1.1"))
        self.assertEqual(force_bytes(inst.item[0].item[0].text), force_bytes("Do you have allergies?"))
        self.assertEqual(force_bytes(inst.item[0].linkId), force_bytes("1"))
        self.assertEqual(force_bytes(inst.item[1].item[0].answer[0].valueString), force_bytes("Male"))
        self.assertEqual(force_bytes(inst.item[1].item[0].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[1].item[0].text), force_bytes("What is your gender?"))
        self.assertEqual(inst.item[1].item[1].answer[0].valueDate.date, FHIRDate("1960-03-13").date)
        self.assertEqual(inst.item[1].item[1].answer[0].valueDate.as_json(), "1960-03-13")
        self.assertEqual(force_bytes(inst.item[1].item[1].linkId), force_bytes("2.2"))
        self.assertEqual(force_bytes(inst.item[1].item[1].text), force_bytes("What is your date of birth?"))
        self.assertEqual(force_bytes(inst.item[1].item[2].answer[0].valueString), force_bytes("The Netherlands"))
        self.assertEqual(force_bytes(inst.item[1].item[2].linkId), force_bytes("2.3"))
        self.assertEqual(force_bytes(inst.item[1].item[2].text), force_bytes("What is your country of birth?"))
        self.assertEqual(force_bytes(inst.item[1].item[3].answer[0].valueString), force_bytes("married"))
        self.assertEqual(force_bytes(inst.item[1].item[3].linkId), force_bytes("2.4"))
        self.assertEqual(force_bytes(inst.item[1].item[3].text), force_bytes("What is your marital status?"))
        self.assertEqual(force_bytes(inst.item[1].linkId), force_bytes("2"))
        self.assertEqual(force_bytes(inst.item[1].text), force_bytes("General questions"))
        self.assertEqual(force_bytes(inst.item[2].item[0].answer[0].valueString), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[0].linkId), force_bytes("3.1"))
        self.assertEqual(force_bytes(inst.item[2].item[0].text), force_bytes("Do you smoke?"))
        self.assertEqual(force_bytes(inst.item[2].item[1].answer[0].valueString), force_bytes("No, but I used to drink"))
        self.assertEqual(force_bytes(inst.item[2].item[1].linkId), force_bytes("3.2"))
        self.assertEqual(force_bytes(inst.item[2].item[1].text), force_bytes("Do you drink alchohol?"))
        self.assertEqual(force_bytes(inst.item[2].linkId), force_bytes("3"))
        self.assertEqual(force_bytes(inst.item[2].text), force_bytes("Intoxications"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testQuestionnaireResponse3(self):
        inst = self.instantiate_from("questionnaireresponse-example-ussg-fht-answers.json")
        self.assertIsNotNone(inst, "Must have instantiated a QuestionnaireResponse instance")
        self.implQuestionnaireResponse3(inst)
        
        js = inst.as_json()
        self.assertEqual("QuestionnaireResponse", js["resourceType"])
        inst2 = questionnaireresponse.QuestionnaireResponse(js)
        self.implQuestionnaireResponse3(inst2)
    
    def implQuestionnaireResponse3(self, inst):
        self.assertEqual(inst.authored.date, FHIRDate("2008-01-17").date)
        self.assertEqual(inst.authored.as_json(), "2008-01-17")
        self.assertEqual(force_bytes(inst.id), force_bytes("ussg-fht-answers"))
        self.assertEqual(inst.item[0].item[0].answer[0].valueDate.date, FHIRDate("2008-01-17").date)
        self.assertEqual(inst.item[0].item[0].answer[0].valueDate.as_json(), "2008-01-17")
        self.assertEqual(force_bytes(inst.item[0].item[0].linkId), force_bytes("0.1"))
        self.assertEqual(force_bytes(inst.item[0].item[0].text), force_bytes("Date Done"))
        self.assertEqual(force_bytes(inst.item[0].linkId), force_bytes("0"))
        self.assertEqual(force_bytes(inst.item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54126-8"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[0].answer[0].valueString), force_bytes("Annie Proband"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54125-0"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[0].linkId), force_bytes("1.1.1"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[0].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[1].answer[0].valueCoding.code), force_bytes("LA3-6"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[1].answer[0].valueCoding.display), force_bytes("Female"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[1].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54131-8"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[1].linkId), force_bytes("1.1.2"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[1].text), force_bytes("Gender"))
        self.assertEqual(inst.item[1].item[0].item[2].answer[0].valueDate.date, FHIRDate("1966-04-04").date)
        self.assertEqual(inst.item[1].item[0].item[2].answer[0].valueDate.as_json(), "1966-04-04")
        self.assertEqual(force_bytes(inst.item[1].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/21112-8"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[2].linkId), force_bytes("1.1.3"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[2].text), force_bytes("Date of Birth"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[3].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54132-6"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[3].linkId), force_bytes("1.1.4"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[3].text), force_bytes("Were you born a twin?"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54128-4"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[4].linkId), force_bytes("1.1.5"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[4].text), force_bytes("Were you adopted?"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54135-9"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[5].linkId), force_bytes("1.1.6"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[5].text), force_bytes("Are your parents related to each other in any way other than marriage?"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].answer[0].item[0].item[0].answer[0].valueCoding.code), force_bytes("[in_i]"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].answer[0].item[0].item[0].answer[0].valueCoding.display), force_bytes("inches"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].answer[0].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://unitsofmeasure.org"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].answer[0].item[0].item[0].linkId), force_bytes("1.1.7.1.1"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].answer[0].item[0].item[0].text), force_bytes("Units"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].answer[0].item[0].linkId), force_bytes("1.1.7.1"))
        self.assertEqual(inst.item[1].item[0].item[6].answer[0].valueDecimal, 63)
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].definition), force_bytes("http://loinc.org/fhir/DataElement/8302-2"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].linkId), force_bytes("1.1.7"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[6].text), force_bytes("Height"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].answer[0].item[0].item[0].answer[0].valueCoding.code), force_bytes("lb"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].answer[0].item[0].item[0].answer[0].valueCoding.display), force_bytes("pounds"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].answer[0].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://unitsofmeasure.org"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].answer[0].item[0].item[0].linkId), force_bytes("1.1.8.1.1"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].answer[0].item[0].item[0].text), force_bytes("Units"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].answer[0].item[0].linkId), force_bytes("1.1.8.1"))
        self.assertEqual(inst.item[1].item[0].item[7].answer[0].valueDecimal, 127)
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].definition), force_bytes("http://loinc.org/fhir/DataElement/29463-7"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].linkId), force_bytes("1.1.8"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[7].text), force_bytes("Weight"))
        self.assertEqual(inst.item[1].item[0].item[8].answer[0].valueDecimal, 22.5)
        self.assertEqual(force_bytes(inst.item[1].item[0].item[8].definition), force_bytes("http://loinc.org/fhir/DataElement/39156-5"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[8].linkId), force_bytes("1.1.9"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[8].text), force_bytes("Body mass index (BMI) [Ratio]"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[9].answer[0].valueCoding.code), force_bytes("LA4457-3"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[9].answer[0].valueCoding.display), force_bytes("White"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[9].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[9].definition), force_bytes("http://loinc.org/fhir/DataElement/54134-2"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[9].linkId), force_bytes("1.1.10"))
        self.assertEqual(force_bytes(inst.item[1].item[0].item[9].text), force_bytes("Race"))
        self.assertEqual(force_bytes(inst.item[1].item[0].linkId), force_bytes("1.1"))
        self.assertEqual(force_bytes(inst.item[1].linkId), force_bytes("1"))
        self.assertEqual(force_bytes(inst.item[1].text), force_bytes("Your health information"))
        self.assertEqual(force_bytes(inst.item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54114-4"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10405-1"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[0].answer[0].valueCoding.display), force_bytes("Daughter"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[1].answer[0].valueString), force_bytes("Susan"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA3-6"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[2].answer[0].valueCoding.display), force_bytes("Female"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[0].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 17)
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[0].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[0].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10415-0"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[0].answer[0].valueCoding.display), force_bytes("Brother"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[1].answer[0].valueString), force_bytes("Brian"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA2-8"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[2].answer[0].valueCoding.display), force_bytes("Male"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[1].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 32)
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[0].answer[0].valueCoding.code), force_bytes("LA10550-4"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[0].answer[0].valueCoding.display), force_bytes("-- Other Cancer"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[0].linkId), force_bytes("2.1.2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[0].text), force_bytes("Disease or Condition"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[1].answer[0].valueCoding.code), force_bytes("LA10397-0"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[1].answer[0].valueCoding.display), force_bytes("30-39"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[1].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[1].linkId), force_bytes("2.1.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].item[1].text), force_bytes("Age at Diagnosis"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].linkId), force_bytes("2.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[1].item[1].text), force_bytes("This family member's history of disease"))
        self.assertEqual(force_bytes(inst.item[2].item[1].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10418-4"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[0].answer[0].valueCoding.display), force_bytes("Sister"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[1].answer[0].valueString), force_bytes("Janet"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA3-6"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[2].answer[0].valueCoding.display), force_bytes("Female"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[2].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 36)
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[0].answer[0].valueCoding.code), force_bytes("LA10536-3"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[0].answer[0].valueCoding.display), force_bytes("-- Breast Cancer"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[0].linkId), force_bytes("2.1.2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[0].text), force_bytes("Disease or Condition"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[1].answer[0].valueCoding.code), force_bytes("LA10397-0"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[1].answer[0].valueCoding.display), force_bytes("30-39"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[1].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[1].linkId), force_bytes("2.1.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].item[1].text), force_bytes("Age at Diagnosis"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].linkId), force_bytes("2.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[2].item[1].text), force_bytes("This family member's history of disease"))
        self.assertEqual(force_bytes(inst.item[2].item[2].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10419-2"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[0].answer[0].valueCoding.display), force_bytes("Nephew"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[1].answer[0].valueString), force_bytes("Ian"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA2-8"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[2].answer[0].valueCoding.display), force_bytes("Male"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[3].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 16)
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[3].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[3].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10420-0"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[0].answer[0].valueCoding.display), force_bytes("Niece"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[1].answer[0].valueString), force_bytes("Helen"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA3-6"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[2].answer[0].valueCoding.display), force_bytes("Female"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[4].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 15)
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[4].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[4].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10416-8"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[0].answer[0].valueCoding.display), force_bytes("Father"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[1].answer[0].valueString), force_bytes("Donald"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA2-8"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[2].answer[0].valueCoding.display), force_bytes("Male"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[5].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 52)
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[5].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[5].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10425-9"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[0].answer[0].valueCoding.display), force_bytes("Paternal Uncle"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[1].answer[0].valueString), force_bytes("Eric"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA2-8"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[2].answer[0].valueCoding.display), force_bytes("Male"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[6].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 56)
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[6].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[6].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10421-8"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[0].answer[0].valueCoding.display), force_bytes("Paternal Aunt"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[1].answer[0].valueString), force_bytes("Fiona"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA3-6"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[2].answer[0].valueCoding.display), force_bytes("Female"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(inst.item[2].item[7].item[0].item[3].answer[0].item[0].item[0].answer[0].valueDecimal, 57)
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54141-7"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Age"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.2"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA33-6"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].answer[0].valueCoding.display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[1].item[0].answer[0].valueCoding.code), force_bytes("LA10543-9"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[1].item[0].answer[0].valueCoding.display), force_bytes("-- Skin Cancer"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[1].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[1].item[0].linkId), force_bytes("2.1.2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[1].item[0].text), force_bytes("Disease or Condition"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[1].linkId), force_bytes("2.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[7].item[1].text), force_bytes("This family member's history of disease"))
        self.assertEqual(force_bytes(inst.item[2].item[7].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10423-4"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[0].answer[0].valueCoding.display), force_bytes("Paternal Grandfather"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[1].answer[0].valueString), force_bytes("Bob"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA2-8"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[2].answer[0].valueCoding.display), force_bytes("Male"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10537-1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[0].answer[0].valueCoding.display), force_bytes("-- Colon Cancer"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54112-8"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Cause of Death"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[1].answer[0].valueCoding.code), force_bytes("LA10400-2"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[1].answer[0].valueCoding.display), force_bytes("OVER 60"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[1].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54113-6"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[1].linkId), force_bytes("2.1.1.4.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].item[1].text), force_bytes("Age at Death"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[0].answer[0].valueCoding.code), force_bytes("LA10537-1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[0].answer[0].valueCoding.display), force_bytes("-- Colon Cancer"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[0].linkId), force_bytes("2.1.2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[0].text), force_bytes("Disease or Condition"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[1].answer[0].valueCoding.code), force_bytes("LA10400-2"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[1].answer[0].valueCoding.display), force_bytes("OVER 60"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[1].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[1].linkId), force_bytes("2.1.2.2"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].item[1].text), force_bytes("Age at Diagnosis"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].linkId), force_bytes("2.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[8].item[1].text), force_bytes("This family member's history of disease"))
        self.assertEqual(force_bytes(inst.item[2].item[8].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10424-2"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[0].answer[0].valueCoding.display), force_bytes("Paternal Grandmother"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54136-7"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[0].linkId), force_bytes("2.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[0].text), force_bytes("Relationship to you"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[1].answer[0].valueString), force_bytes("Claire"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54138-3"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[1].linkId), force_bytes("2.1.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[1].text), force_bytes("Name"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[2].answer[0].valueCoding.code), force_bytes("LA3-6"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[2].answer[0].valueCoding.display), force_bytes("Female"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[2].definition), force_bytes("http://loinc.org/fhir/DataElement/54123-5"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[2].linkId), force_bytes("2.1.1.3"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[2].text), force_bytes("Gender"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].answer[0].item[0].answer[0].valueString), force_bytes("Lou Gehrigs"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].answer[0].item[0].linkId), force_bytes("2.1.1.4.1.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].answer[0].item[0].text), force_bytes("Please specify"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].answer[0].valueCoding.code), force_bytes("LA10589-2"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].answer[0].valueCoding.display), force_bytes("-- Other/Unexpected"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].definition), force_bytes("http://loinc.org/fhir/DataElement/54112-8"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].linkId), force_bytes("2.1.1.4.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[0].text), force_bytes("Cause of Death"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[1].answer[0].valueCoding.code), force_bytes("LA10400-2"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[1].answer[0].valueCoding.display), force_bytes("OVER 60"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[1].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[1].definition), force_bytes("http://loinc.org/fhir/DataElement/54113-6"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[1].linkId), force_bytes("2.1.1.4.1.2"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].item[1].text), force_bytes("Age at Death"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].item[0].linkId), force_bytes("2.1.1.4.1"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].definition), force_bytes("http://loinc.org/fhir/DataElement/54139-1"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].linkId), force_bytes("2.1.1.4"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[3].text), force_bytes("Living?"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[4].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[4].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[4].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[4].definition), force_bytes("http://loinc.org/fhir/DataElement/54121-9"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[4].linkId), force_bytes("2.1.1.5"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[4].text), force_bytes("Was this person born a twin?"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[5].answer[0].valueCoding.code), force_bytes("LA32-8"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[5].answer[0].valueCoding.display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[5].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[5].definition), force_bytes("http://loinc.org/fhir/DataElement/54122-7"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[5].linkId), force_bytes("2.1.1.6"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].item[5].text), force_bytes("Was this person adopted?"))
        self.assertEqual(force_bytes(inst.item[2].item[9].item[0].linkId), force_bytes("2.1.1"))
        self.assertEqual(force_bytes(inst.item[2].item[9].linkId), force_bytes("2.1"))
        self.assertEqual(force_bytes(inst.item[2].linkId), force_bytes("2"))
        self.assertEqual(force_bytes(inst.item[2].text), force_bytes("Family member health information"))
        self.assertEqual(force_bytes(inst.status), force_bytes("in-progress"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testQuestionnaireResponse4(self):
        inst = self.instantiate_from("questionnaireresponse-example-gcs.json")
        self.assertIsNotNone(inst, "Must have instantiated a QuestionnaireResponse instance")
        self.implQuestionnaireResponse4(inst)
        
        js = inst.as_json()
        self.assertEqual("QuestionnaireResponse", js["resourceType"])
        inst2 = questionnaireresponse.QuestionnaireResponse(js)
        self.implQuestionnaireResponse4(inst2)
    
    def implQuestionnaireResponse4(self, inst):
        self.assertEqual(inst.authored.date, FHIRDate("2014-12-11T04:44:16Z").date)
        self.assertEqual(inst.authored.as_json(), "2014-12-11T04:44:16Z")
        self.assertEqual(force_bytes(inst.id), force_bytes("gcs"))
        self.assertEqual(force_bytes(inst.item[0].answer[0].valueCoding.code), force_bytes("LA6560-2"))
        self.assertEqual(force_bytes(inst.item[0].answer[0].valueCoding.display), force_bytes("Confused"))
        self.assertEqual(force_bytes(inst.item[0].answer[0].valueCoding.extension[0].url), force_bytes("http://hl7.org/fhir/StructureDefinition/iso21090-CO-value"))
        self.assertEqual(inst.item[0].answer[0].valueCoding.extension[0].valueDecimal, 4)
        self.assertEqual(force_bytes(inst.item[0].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[0].linkId), force_bytes("1.1"))
        self.assertEqual(force_bytes(inst.item[1].answer[0].valueCoding.code), force_bytes("LA6566-9"))
        self.assertEqual(force_bytes(inst.item[1].answer[0].valueCoding.display), force_bytes("Localizing pain"))
        self.assertEqual(force_bytes(inst.item[1].answer[0].valueCoding.extension[0].url), force_bytes("http://hl7.org/fhir/StructureDefinition/iso21090-CO-value"))
        self.assertEqual(inst.item[1].answer[0].valueCoding.extension[0].valueDecimal, 5)
        self.assertEqual(force_bytes(inst.item[1].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[1].linkId), force_bytes("1.2"))
        self.assertEqual(force_bytes(inst.item[2].answer[0].valueCoding.code), force_bytes("LA6556-0"))
        self.assertEqual(force_bytes(inst.item[2].answer[0].valueCoding.display), force_bytes("Eyes open spontaneously"))
        self.assertEqual(force_bytes(inst.item[2].answer[0].valueCoding.extension[0].url), force_bytes("http://hl7.org/fhir/StructureDefinition/iso21090-CO-value"))
        self.assertEqual(inst.item[2].answer[0].valueCoding.extension[0].valueDecimal, 4)
        self.assertEqual(force_bytes(inst.item[2].answer[0].valueCoding.system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.item[2].linkId), force_bytes("1.3"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testQuestionnaireResponse5(self):
        inst = self.instantiate_from("questionnaireresponse-example-bluebook.json")
        self.assertIsNotNone(inst, "Must have instantiated a QuestionnaireResponse instance")
        self.implQuestionnaireResponse5(inst)
        
        js = inst.as_json()
        self.assertEqual("QuestionnaireResponse", js["resourceType"])
        inst2 = questionnaireresponse.QuestionnaireResponse(js)
        self.implQuestionnaireResponse5(inst2)
    
    def implQuestionnaireResponse5(self, inst):
        self.assertEqual(inst.authored.date, FHIRDate("2013-02-19T14:15:00+10:00").date)
        self.assertEqual(inst.authored.as_json(), "2013-02-19T14:15:00+10:00")
        self.assertEqual(force_bytes(inst.id), force_bytes("bb"))
        self.assertEqual(force_bytes(inst.item[0].item[0].item[0].answer[0].valueString), force_bytes("Cathy Jones"))
        self.assertEqual(force_bytes(inst.item[0].item[0].item[0].linkId), force_bytes("nameOfChild"))
        self.assertEqual(force_bytes(inst.item[0].item[0].item[0].text), force_bytes("Name of child"))
        self.assertEqual(force_bytes(inst.item[0].item[0].item[1].answer[0].valueCoding.code), force_bytes("f"))
        self.assertEqual(force_bytes(inst.item[0].item[0].item[1].linkId), force_bytes("sex"))
        self.assertEqual(force_bytes(inst.item[0].item[0].item[1].text), force_bytes("Sex"))
        self.assertEqual(force_bytes(inst.item[0].item[0].linkId), force_bytes("group"))
        self.assertEqual(inst.item[0].item[1].item[0].answer[0].valueDecimal, 3.25)
        self.assertEqual(force_bytes(inst.item[0].item[1].item[0].linkId), force_bytes("birthWeight"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[0].text), force_bytes("Birth weight (kg)"))
        self.assertEqual(inst.item[0].item[1].item[1].answer[0].valueDecimal, 44.3)
        self.assertEqual(force_bytes(inst.item[0].item[1].item[1].linkId), force_bytes("birthLength"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[1].text), force_bytes("Birth length (cm)"))
        self.assertEqual(inst.item[0].item[1].item[2].answer[0].item[0].item[0].answer[0].valueDate.date, FHIRDate("1972-11-30").date)
        self.assertEqual(inst.item[0].item[1].item[2].answer[0].item[0].item[0].answer[0].valueDate.as_json(), "1972-11-30")
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].answer[0].item[0].item[0].linkId), force_bytes("vitaminKDose1"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].answer[0].item[0].item[0].text), force_bytes("1st dose"))
        self.assertEqual(inst.item[0].item[1].item[2].answer[0].item[0].item[1].answer[0].valueDate.date, FHIRDate("1972-12-11").date)
        self.assertEqual(inst.item[0].item[1].item[2].answer[0].item[0].item[1].answer[0].valueDate.as_json(), "1972-12-11")
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].answer[0].item[0].item[1].linkId), force_bytes("vitaminKDose2"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].answer[0].item[0].item[1].text), force_bytes("2nd dose"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].answer[0].item[0].linkId), force_bytes("vitaminKgivenDoses"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].answer[0].valueCoding.code), force_bytes("INJECTION"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].linkId), force_bytes("vitaminKgiven"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[2].text), force_bytes("Vitamin K given"))
        self.assertEqual(inst.item[0].item[1].item[3].answer[0].item[0].answer[0].valueDate.date, FHIRDate("1972-12-04").date)
        self.assertEqual(inst.item[0].item[1].item[3].answer[0].item[0].answer[0].valueDate.as_json(), "1972-12-04")
        self.assertEqual(force_bytes(inst.item[0].item[1].item[3].answer[0].item[0].linkId), force_bytes("hepBgivenDate"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[3].answer[0].item[0].text), force_bytes("Date given"))
        self.assertTrue(inst.item[0].item[1].item[3].answer[0].valueBoolean)
        self.assertEqual(force_bytes(inst.item[0].item[1].item[3].linkId), force_bytes("hepBgiven"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[3].text), force_bytes("Hep B given y / n"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[4].answer[0].valueString), force_bytes("Already able to speak Chinese"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[4].linkId), force_bytes("abnormalitiesAtBirth"))
        self.assertEqual(force_bytes(inst.item[0].item[1].item[4].text), force_bytes("Abnormalities noted at birth"))
        self.assertEqual(force_bytes(inst.item[0].item[1].linkId), force_bytes("neonatalInformation"))
        self.assertEqual(force_bytes(inst.item[0].item[1].text), force_bytes("Neonatal Information"))
        self.assertEqual(force_bytes(inst.item[0].linkId), force_bytes("birthDetails"))
        self.assertEqual(force_bytes(inst.item[0].text), force_bytes("Birth details - To be completed by health professional"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))

